aboutsummaryrefslogtreecommitdiff
path: root/moderation.go
diff options
context:
space:
mode:
Diffstat (limited to 'moderation.go')
-rw-r--r--moderation.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/moderation.go b/moderation.go
index ae4d620..719606c 100644
--- a/moderation.go
+++ b/moderation.go
@@ -6,11 +6,11 @@ import (
"github.com/anon55555/mt"
)
// Kick sends mt.ToCltDisco with the specified custom reason
// and closes the ClientConn.
func (cc *ClientConn) Kick(reason string) {
go func() {
- ack, _ := cc.SendCmd(&mt.ToCltDisco{
+ ack, _ := cc.SendCmd(&mt.ToCltKick{
Reason: mt.Custom,
Custom: reason,
})
@@ -6,11 +6,11 @@ import (
"github.com/anon55555/mt"
)
-// Kick sends mt.ToCltDisco with the specified custom reason
+// Kick sends mt.ToCltKick with the specified custom reason
// and closes the ClientConn.
func (cc *ClientConn) Kick(reason string) {